import os

from tornado.httpserver import HTTPServer
from tornado.ioloop import IOLoop
from tornado.wsgi import WSGIContainer

from stnm.web.app import app

PORT = os.environ.get("WEB_PORT") or 8081
HOST = os.environ.get("WEB_HOST") or "127.0.0.1"


def callback():
    print("-" * 40)
    print("Server running at {}:{}".format(HOST, PORT))
    print("STNM API http://{}:{}/api".format(HOST, PORT))
    print("Mining Bot Web UI http://{}:{}/ui".format(HOST, PORT))
    print("-" * 40)


def web():
    http_server = HTTPServer(WSGIContainer(app))
    http_server.listen(PORT, address=HOST)
    IOLoop.instance().add_callback(callback)

    try:
        IOLoop.instance().start()
    except KeyboardInterrupt:
        print("\nBye")



import unittest

from .config_test import ConfigTestCase


def make_suite():
    test_1 = unittest.TestLoader().loadTestsFromTestCase(ConfigTestCase)

    suite = unittest.TestSuite(
        [test_1, ]
    )

    return suite


def do_tests():
    runner = unittest.TextTestRunner()
    test_suite = make_suite()
    runner.run(test_suite)



import unittest

from stnm.cli.config import config_input_parser, InvalidConfigEntry, UnavailableConfigParameter, InvalidValue


class ConfigTestCase(unittest.TestCase):
    @classmethod
    def setUpClass(cls):
        cls.maxDiff = 1000

    def test_parse_01(self):
        resp = config_input_parser("node.miner=true,node.seed=True,burnchain.peer_port=2000,node.seed=abccd1df")
        self.assertEqual(str(resp), "[<node.miner=True>, <node.seed=True>, <burnchain.peer_port=2000>, <node.seed=abccd1df>]")

    def test_parse_invalid_entry_02(self):
        with self.assertRaises(InvalidConfigEntry) as ctx:
            config_input_parser("foo")

        self.assertEqual("InvalidConfigEntry" in str(type(ctx.exception)), True)

        with self.assertRaises(InvalidConfigEntry) as ctx:
            config_input_parser("foo.bar")

        self.assertEqual("InvalidConfigEntry" in str(type(ctx.exception)), True)

    def test_parse_unavailable_config_parameter_03(self):
        with self.assertRaises(UnavailableConfigParameter) as ctx:
            config_input_parser("foo.bar=baz")

        self.assertEqual("UnavailableConfigParameter" in str(type(ctx.exception)), True)

    def test_parse_invalid_value_04(self):
        with self.assertRaises(InvalidValue) as ctx:
            config_input_parser("node.miner=12")

        self.assertEqual("InvalidValue" in str(type(ctx.exception)), True)



import argparse
import os
import sys

assert sys.version_info[0] == 3 and sys.version_info[1] >= 5, "Requires Python 3.5 or newer"

sys.path.append(os.path.abspath(os.path.join(os.path.dirname(__file__))))

if sys.platform not in ["linux", "linux2", "darwin"]:
    print("stnm supports only macos and linux")
    sys.exit(1)


def main():
    parser = argparse.ArgumentParser(description="")
    cmd_list = (
        "install",
        "status",
        "start",
        "stop",
        "config",
        "web",
        "test"
    )

    parser.add_argument("cmd", choices=cmd_list, nargs="?", default="")
    parser.add_argument("arg", nargs="?", default="")

    args = parser.parse_args()
    cmd = args.cmd
    arg = args.arg

    if cmd == "config" and arg == "":
        parser.error("configuration parameter required. e.g node.miner=true")

    from stnm import main
    main(cmd, arg)


if __name__ == '__main__':
    main()
